==> nomachine-8.9.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAuth::BEGIN{package NXAuth;no warnings;require warnings;do{
"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub NXAuth::BEGIN{package NXAuth;no
 warnings;require Exporter;do{"\x45\x78\x70\x6f\x72\x74\x65\x72"->import};}sub 
NXAuth::BEGIN{package NXAuth;no warnings;require NXMsg;do{"\x4e\x58\x4d\x73\x67"
->import};}sub NXAuth::BEGIN{package NXAuth;no warnings;require Common::NXInfo;
do{"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x49\x6e\x66\x6f"->import};}package 
NXAuth;no warnings;(our (@ISA)="\x45\x78\x70\x6f\x72\x74\x65\x72");(our (@EXPORT
)=("\x67\x65\x74\x4e\x58\x41\x75\x74\x68\x54\x79\x70\x65",
"\x69\x73\x53\x53\x48\x44\x41\x75\x74\x68",
"\x69\x73\x4e\x6f\x74\x53\x53\x48\x44\x41\x75\x74\x68","\x69\x73\x4e\x58\x44",
"\x69\x73\x4e\x6f\x74\x4e\x58\x44",
"\x69\x73\x4e\x6f\x6d\x61\x63\x68\x69\x6e\x65",
"\x69\x73\x53\x79\x73\x74\x65\x6d"));($type=(""));($typeNomachine=
"\x6e\x6f\x6d\x61\x63\x68\x69\x6e\x65");($typeSystem="\x73\x79\x73\x74\x65\x6d")
;($typeNXD="\x6e\x78\x64");($salt=(""));($sshConnection=(-(0x11c8+ 2562-0x1bc9))
);sub init{(my $environmentValue=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (defined (
$environmentValue)){if (($environmentValue ne (""))){setNXD ();}}}sub 
isSSHConnection{if (($sshConnection!=(-(0x09a3+ 3543-0x1779)))){return (
$sshConnection);}($sshConnection=(0x0418+ 6936-0x1f30));(my $env=
libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (defined ($env))
{if (($env ne (""))){($sshConnection=(0x02ab+ 4193-0x130b));}}return (
$sshConnection);}sub initConnectionType{if (isNotNXD ()){if ((defined (
$GLOBAL::LOGGED_USER)and ($GLOBAL::LOGGED_USER ne ("")))){setSystem ();}else{
setNomachine ();}}}sub getNXAuthType{return ($type);}sub isSSHDAuth{if ((defined
 ($GLOBAL::UseSSHAuthentication)and ($GLOBAL::UseSSHAuthentication eq 
"\x65\x6e\x61\x62\x6c\x65\x64"))){return ((0x1199+ 2004-0x196c));}else{return (
(0x0a90+ 5295-0x1f3f));}}sub isNotSSHDAuth{return ((!isSSHDAuth ()));}sub setNXD
{Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeNXD)."\x27\x2e"));($type=$typeNXD);}sub isTypeSet{if ((getNXAuthType ()ne 
(""))){return ((0x0bf6+ 5932-0x2321));}return ((0x0a1c+ 3913-0x1965));}sub isNXD
{if (($type eq $typeNXD)){return ((0x12e1+ 969-0x16a9));}return (
(0x0a55+ 2823-0x155c));}sub isNotNXD{return ((!isNXD ()));}sub 
getActiveConnectionPort{if ((isNXD ()eq "\x31")){return (NXNodeInfo::getNxdPort 
());}else{return ($GLOBAL::SSHPort);}}sub setNomachine{if ((not (isTypeSet ())))
{Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeNomachine)."\x27\x2e"));($type=$typeNomachine);}}sub isNomachine{if (($type
 eq $typeNomachine)){return ((0x0059+ 6002-0x17ca));}return (
(0x0b34+ 2078-0x1352));}sub getTypeNomachine{return ($typeNomachine);}sub 
setSystem{if ((not (isTypeSet ()))){Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeSystem)."\x27\x2e"));($type=$typeSystem);}}sub isSystem{if (($type eq 
$typeSystem)){return ((0x0f70+ 5270-0x2405));}return ((0x0461+ 5171-0x1894));}
sub getTypeSystem{return ($typeSystem);}sub checkIsSshAvailable{
initConnectionType ();if (isSystem ()){if (NXLicense::isSshFeature ()){if ((not 
(NXSystemDaemons::isSSHEnabledInConfig ()))){Logger::debug (
"\x53\x53\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x64\x69\x73\x61\x62\x6c\x65\x64"
);return ((0x06e2+ 435-0x0894));}}else{Logger::debug (
"\x53\x53\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6e\x6f\x74\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64"
);return ((0x2574+ 373-0x26e7));}}return ((0x065a+ 6265-0x1ed3));}sub 
NxServerUserSystemAuth{(my $hello_data=shift (@_));(my $helloMessage=((((
"\x68\x65\x6c\x6c\x6f\x20".$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_LOGIN_LOGIN}).
"\x20").$GLOBAL::LOGGED_USER).("\x20".$hello_data)));(my ($error_msg,$result)=
NXServer2Server::execute ($GLOBAL::MSG_GET_COMMAND,$helloMessage,"\x32\x35\x30",
(""),$GLOBAL::MSG_LOGIN_PASSWORD_AUTH_COOKIE,(""),"\x32\x35\x30",(""),
$GLOBAL::MSG_LOGIN_OK,("")));if ($result){NXMsg::register_error (
"\x4e\x58\x41\x75\x74\x68",
"\x65\x43\x61\x6e\x6e\x6f\x74\x41\x75\x74\x68\x6f\x72\x69\x7a\x65",
(0x0652+  72-0x04a6),
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x75\x74\x68\x6f\x72\x69\x7a\x65\x20\x77\x69\x74\x68\x20\x63\x6f\x6f\x6b\x69\x65"
);NXMsg::error (
"\x65\x43\x61\x6e\x6e\x6f\x74\x41\x75\x74\x68\x6f\x72\x69\x7a\x65",
"\x4e\x58\x41\x75\x74\x68");NXShell::handle_command ("\x65\x78\x69\x74");}return
 ((0x1615+ 2237-0x1ed2));}sub addCookie{(my $inputfilename=shift (@_));(my $dpyname
=shift (@_));(my $protoname=shift (@_));(my $hexkey=shift (@_));if (((not (
defined ($inputfilename)))or ($inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x1ef3+ 1410-0x2474));}if (((not (defined ($dpyname)))or ($dpyname eq
 ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x13d7+ 2465-0x1d77));}if (((not (defined ($protoname)))or (
$protoname eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x6e\x61\x6d\x65\x2e"
);return ((0x0fd0+ 2855-0x1af6));}if (((not (defined ($hexkey)))or ($hexkey eq 
("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x68\x65\x78\x6b\x65\x79\x2e"
);return ((0x09f5+ 5693-0x2031));}(my $returnValue=libnxh::NXAddCookie (
$inputfilename,$dpyname,$protoname,$hexkey));if (($returnValue!=
(0x0086+ 1502-0x0664))){(my $errorInt=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());Logger::warning (((((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x41\x64\x64\x43\x6f\x6f\x6b\x69\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x20\x63\x6f\x64\x65\x20\x5b"
.$errorInt)."\x5d\x20\x5b").$errorString)."\x5d"));}return ($returnValue);}sub 
isKnowHostSet{if ((defined ($setKnownhostNul)and ($setKnownhostNul==
(0x063a+ 4863-0x1938)))){return ((0x04d3+ 4856-0x17ca));}return (
(0x023b+ 7138-0x1e1d));}sub generateSalt{Logger::debug (
"\x47\x65\x6e\x65\x72\x61\x74\x69\x6e\x67\x20\x73\x61\x6c\x74\x2e");($salt=
main::get_unique_id ());}sub getSalt{return ($salt);}return (
(0x04cc+ 4192-0x152b));

==> nomachine-8.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAuth.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAuth::BEGIN{package NXAuth;no warnings;require warnings;do{
"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub NXAuth::BEGIN{package NXAuth;no
 warnings;require Exporter;do{"\x45\x78\x70\x6f\x72\x74\x65\x72"->import};}sub 
NXAuth::BEGIN{package NXAuth;no warnings;require NXMsg;do{"\x4e\x58\x4d\x73\x67"
->import};}sub NXAuth::BEGIN{package NXAuth;no warnings;require Common::NXInfo;
do{"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x49\x6e\x66\x6f"->import};}package 
NXAuth;no warnings;(our (@ISA)="\x45\x78\x70\x6f\x72\x74\x65\x72");(our (@EXPORT
)=("\x67\x65\x74\x4e\x58\x41\x75\x74\x68\x54\x79\x70\x65",
"\x69\x73\x53\x53\x48\x44\x41\x75\x74\x68",
"\x69\x73\x4e\x6f\x74\x53\x53\x48\x44\x41\x75\x74\x68","\x69\x73\x4e\x58\x44",
"\x69\x73\x4e\x6f\x74\x4e\x58\x44",
"\x69\x73\x4e\x6f\x6d\x61\x63\x68\x69\x6e\x65",
"\x69\x73\x53\x79\x73\x74\x65\x6d"));($type=(""));($typeNomachine=
"\x6e\x6f\x6d\x61\x63\x68\x69\x6e\x65");($typeSystem="\x73\x79\x73\x74\x65\x6d")
;($typeNXD="\x6e\x78\x64");($salt=(""));($sshConnection=(-(0x04c7+ 8457-0x25cf))
);sub init{(my $environmentValue=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (defined (
$environmentValue)){if (($environmentValue ne (""))){setNXD ();}}}sub 
isSSHConnection{if (($sshConnection!=(-(0x0405+ 8142-0x23d2)))){return (
$sshConnection);}($sshConnection=(0x0129+ 7125-0x1cfe));(my $env=
libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (defined ($env))
{if (($env ne (""))){($sshConnection=(0x095d+ 5594-0x1f36));}}return (
$sshConnection);}sub initConnectionType{if (isNotNXD ()){if ((defined (
$GLOBAL::LOGGED_USER)and ($GLOBAL::LOGGED_USER ne ("")))){setSystem ();}else{
setNomachine ();}}}sub getNXAuthType{return ($type);}sub isSSHDAuth{if ((defined
 ($GLOBAL::UseSSHAuthentication)and ($GLOBAL::UseSSHAuthentication eq 
"\x65\x6e\x61\x62\x6c\x65\x64"))){return ((0x1328+ 4368-0x2437));}else{return (
(0x0628+ 2590-0x1046));}}sub isNotSSHDAuth{return ((!isSSHDAuth ()));}sub setNXD
{Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeNXD)."\x27\x2e"));($type=$typeNXD);}sub isTypeSet{if ((getNXAuthType ()ne 
(""))){return ((0x1c29+ 2501-0x25ed));}return ((0x07cf+ 4597-0x19c4));}sub isNXD
{if (($type eq $typeNXD)){return ((0x06a0+ 5341-0x1b7c));}return (
(0x025a+ 5546-0x1804));}sub isNotNXD{return ((!isNXD ()));}sub 
getActiveConnectionPort{if ((isNXD ()eq "\x31")){return (NXNodeInfo::getNxdPort 
());}else{return ($GLOBAL::SSHPort);}}sub setNomachine{if ((not (isTypeSet ())))
{Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeNomachine)."\x27\x2e"));($type=$typeNomachine);}}sub isNomachine{if (($type
 eq $typeNomachine)){return ((0x1b5d+ 2434-0x24de));}return (
(0x1488+ 4650-0x26b2));}sub getTypeNomachine{return ($typeNomachine);}sub 
setSystem{if ((not (isTypeSet ()))){Logger::debug (((
"\x4e\x58\x41\x75\x74\x68\x3a\x20\x53\x65\x74\x20\x74\x79\x70\x65\x20\x27".
$typeSystem)."\x27\x2e"));($type=$typeSystem);}}sub isSystem{if (($type eq 
$typeSystem)){return ((0x0223+ 576-0x0462));}return ((0x0fdf+ 3954-0x1f51));}sub
 getTypeSystem{return ($typeSystem);}sub checkIsSshAvailable{initConnectionType 
();if (isSystem ()){if (NXLicense::isSshFeature ()){if ((not (
NXSystemDaemons::isSSHEnabledInConfig ()))){Logger::debug (
"\x53\x53\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x64\x69\x73\x61\x62\x6c\x65\x64"
);return ((0x0e61+ 3768-0x1d18));}}else{Logger::debug (
"\x53\x53\x48\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6e\x6f\x74\x20\x73\x75\x70\x70\x6f\x72\x74\x65\x64"
);return ((0x1125+ 4343-0x221a));}}return ((0x11f0+ 2835-0x1d03));}sub 
NxServerUserSystemAuth{(my $hello_data=shift (@_));(my $helloMessage=((((
"\x68\x65\x6c\x6c\x6f\x20".$GLOBAL::MESSAGES_FORMAT{$GLOBAL::MSG_LOGIN_LOGIN}).
"\x20").$GLOBAL::LOGGED_USER).("\x20".$hello_data)));(my ($error_msg,$result)=
NXServer2Server::execute ($GLOBAL::MSG_GET_COMMAND,$helloMessage,"\x32\x35\x30",
(""),$GLOBAL::MSG_LOGIN_PASSWORD_AUTH_COOKIE,(""),"\x32\x35\x30",(""),
$GLOBAL::MSG_LOGIN_OK,("")));if ($result){NXMsg::register_error (
"\x4e\x58\x41\x75\x74\x68",
"\x65\x43\x61\x6e\x6e\x6f\x74\x41\x75\x74\x68\x6f\x72\x69\x7a\x65",
(0x0870+ 810-0x09a6),
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x75\x74\x68\x6f\x72\x69\x7a\x65\x20\x77\x69\x74\x68\x20\x63\x6f\x6f\x6b\x69\x65"
);NXMsg::error (
"\x65\x43\x61\x6e\x6e\x6f\x74\x41\x75\x74\x68\x6f\x72\x69\x7a\x65",
"\x4e\x58\x41\x75\x74\x68");NXShell::handle_command ("\x65\x78\x69\x74");}return
 ((0x0098+ 6945-0x1bb9));}sub addCookie{(my $inputfilename=shift (@_));(my $dpyname
=shift (@_));(my $protoname=shift (@_));(my $hexkey=shift (@_));if (((not (
defined ($inputfilename)))or ($inputfilename eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x69\x6e\x70\x75\x74\x20\x66\x69\x6c\x65\x20\x6e\x61\x6d\x65\x2e"
);return ((0x1e56+ 1804-0x2561));}if (((not (defined ($dpyname)))or ($dpyname eq
 ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x73\x70\x6c\x61\x79\x2e"
);return ((0x10f6+ 1044-0x1509));}if (((not (defined ($protoname)))or (
$protoname eq ("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x70\x72\x6f\x74\x6f\x6e\x61\x6d\x65\x2e"
);return ((0x1653+ 3057-0x2243));}if (((not (defined ($hexkey)))or ($hexkey eq 
("")))){Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x61\x64\x64\x20\x63\x6f\x6f\x6b\x69\x65\x2c\x20\x6d\x69\x73\x73\x69\x6e\x67\x20\x68\x65\x78\x6b\x65\x79\x2e"
);return ((0x0608+ 7050-0x2191));}(my $returnValue=libnxh::NXAddCookie (
$inputfilename,$dpyname,$protoname,$hexkey));if (($returnValue!=
(0x09a4+ 128-0x0a24))){(my $errorInt=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());Logger::warning (((((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x41\x64\x64\x43\x6f\x6f\x6b\x69\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x77\x69\x74\x68\x20\x65\x72\x72\x6f\x72\x20\x63\x6f\x64\x65\x20\x5b"
.$errorInt)."\x5d\x20\x5b").$errorString)."\x5d"));}return ($returnValue);}sub 
isKnowHostSet{if ((defined ($setKnownhostNul)and ($setKnownhostNul==
(0x1131+ 2310-0x1a36)))){return ((0x0311+ 8665-0x24e9));}return (
(0x0e67+ 793-0x1180));}sub generateSalt{Logger::debug (
"\x47\x65\x6e\x65\x72\x61\x74\x69\x6e\x67\x20\x73\x61\x6c\x74\x2e");($salt=
main::get_unique_id ());}sub getSalt{return ($salt);}return (
(0x1b54+ 693-0x1e08));
